*********************************************************************************
/*
# Analysis (table and figure numbering follows that of the manuscript 
	-- use 'control+f' to find a specific code chunk

# The Political Economy of Life Satisfaction

- Nisha Bellinger
- Jonathan Krieckhaus
- Byunghwan Son (contact: bson3@gmu.edu)
*/
*********************************************************************************
clear

global data "YYYYY" // just set up a folder in your computer for your data for analysis to be stored. 

cd $data

set scheme s1color

use data, clear


* Tables 2

** nothing but the core covariates (no controls whatsoever)
reg sat c.income##c.fh , cl(code) 

	eststo fe001
	
reg sat c.income##c.lngdppc , cl(code)

	eststo fe002

** No interaction for H1

reg sat income fh lngdppc trust ideo male age edu growth lninfl ///
	, cl(code)	
	
	eststo base1
		
reg sat income fh lngdppc trust ideo male age edu growth lninfl ///
	i.code, cl(code)	
	
	eststo base2
	
reg sat income fh lngdppc trust ideo male age edu growth lninfl ///
	i.year, cl(code)	

	eststo base3
	
reg sat income fh lngdppc trust ideo male age edu growth lninfl ///
	i.code i.year, cl(code)	

	eststo base4
	
reg sat income p_polity2 lngdppc trust ideo male age edu growth lninfl ///
	i.code i.year, cl(code)	

	eststo base5
	
** curvilinear effect of age?

reg sat income fh lngdppc trust ideo male c.age##c.age edu growth lninfl ///
	i.code i.year, cl(code)	
	
	eststo basecurve


*** Figure 2

	margins, at(age = (15 (1) 99))
	marginsplot, name(age, replace) recast(line) recastci(rarea) ///
		plotopt(lw(thick)) ciopt(lc(white) fintensity(25)) ///
		title("") ytitle("life satisfaction") xtitle("age") ytitle("") yline(0)
		
		gr export age.png, replace
	
esttab base1 base2 base3 base4 base5 basecurve using table2.rtf , ///	
	long replace se(3) b(3) star(* 0.10 ** 0.05 *** 0.01) brackets ///
	mlabels(none) modelwidth(5) varwidth(20) /// 
	keep(income lngdppc fh p_polity2 trust ideo male ///
	age c.age#c.age edu growth ///
	lninfl) nogaps stats(r2 N)
	
		

** table 3

*** no FEs
reg sat c.income##c.fh lngdppc trust ideo male age edu growth lninfl ///
	, cl(code)
	
	eststo fe01
	
reg sat c.income##c.lngdppc fh trust ideo male age edu growth lninfl ///
	, cl(code)

	eststo fe02
	
*** country FEs

reg sat c.income##c.fh lngdppc trust ideo male age edu growth lninfl ///
	i.code, cl(code)
	
	eststo fe11
	
reg sat c.income##c.lngdppc fh trust ideo male age edu growth lninfl ///
	i.code, cl(code)	
	
	eststo fe12
	
*** year FEs	

reg sat c.income##c.fh lngdppc trust ideo male age edu growth lninfl ///
	i.year, cl(code)
	
	eststo fe21
	
reg sat c.income##c.lngdppc fh trust ideo male age edu growth lninfl ///
	i.year, cl(code)	
	
	eststo fe22

*** TWFE

reg sat c.income##c.fh lngdppc trust ideo male age edu growth lninfl ///
	i.code i.year, cl(code) 
	
	eststo fe31
	
	
*** Figure 3
	
	margins, dydx(income) at(fh = (2 (1) 14))
	marginsplot, name(fe1, replace) recast(line) recastci(rarea) ///
		plotopt(lw(thick)) ciopt(lc(white) fintensity(25)) ///
		title("") xtitle("Freedom House") ytitle("") yline(0)
		
		
		* using polity instead
		
	reg sat c.income##c.p_polity2 lngdppc trust ideo male age edu growth lninfl ///
	i.code i.year, cl(code)
	
	margins, dydx(income) at(p_polity2 = (-10 (1) 10))
	marginsplot, name(polity, replace) recast(line) recastci(rarea) ///
		plotopt(lw(thick)) ciopt(lc(white) fintensity(25)) ///
		title("") xtitle("POLITY") ytitle("") yline(0)
		
		gr export polity.png, replace
		gr combine fe1 polity, b1title("Democracy measures") /// 
		l1title("Life Satisfaction")
		gr export fhpolity.png, replace
	
reg sat c.income##c.lngdppc fh trust ideo male age edu growth lninfl ///
	i.code i.year, cl(code)	
	
	eststo fe32
	
	margins, dydx(income) at(lngdppc = (6 (1) 12))
	marginsplot, name(fe2, replace) recast(line) recastci(rarea) ///
		plotopt(lw(thick)) ciopt(lc(white) fintensity(25)) ///
		title("") xtitle("ln(GDP per capita)") ytitle("") yline(0)

	gr combine fe1 fe2
	gr export fe.png, replace
		
	
esttab fe001 fe002 fe11 fe12 fe21 fe22 fe31 fe32 using table2.rtf , ///	
	long replace se(3) b(3) star(* 0.10 ** 0.05 *** 0.01) brackets ///
	mlabels(none) modelwidth(5) varwidth(20) /// 
	keep(income lngdppc fh trust ideo male age edu growth ///
	lninfl c.income#c.fh c.income#c.lngdppc) nogaps R2

	
********************************
* Wild Cluster Bootstraop
// concerning an unbalanced cluster structuer (as per R1)
// referencce: 
**** https://www.stata.com/new-in-stata/wild-cluster-bootstrap-inference/
**** https://www.stata.com/symposiums/economics21/slides/Econ21_Web.pdf
**** https://journals.sagepub.com/doi/pdf/10.1177/1536867X19830877

* wildbootstrap reg sat c.income##c.fh lngdppc trust ideo male age edu growth lninfl ///
	i.code i.year, cl(code) rseed(12345)	// needs the latest Stata?

* boottest

ssc install boottest, replace

reg sat c.income##c.fh lngdppc trust ideo male age edu growth lninfl ///
	i.code i.year, cl(code)
	
boottest income, cluster(code)	nograph
* boottest income // the same result

********************************

* to compare w/ the original mixed effect results

cd $data
use temp1, clear

xtmixed sat c.income##c.fh lngdppc ///
	trust ideo male age edu growth lninfl  ///
	|| id:, vce(robust) mle cov(unstructured) 	
	
********************************

* Figure 4

* standardized substantive effect figure (covariates)
** FH conditioning
local sd "income fh lngdppc trust ideo male age edu growth lninfl"
foreach Y of local sd {
sum `Y' 
gen `Y'_sd = (`Y')/r(sd) 
_crcslbl `Y'_sd `Y'
}
*			

label variable lninfl_sd "ln(Inflation)"
label variable male_sd "Male"


reg sat c.income_sd##c.fh lngdppc_sd trust_sd ideo_sd male_sd ///
	age_sd edu_sd growth_sd lninfl_sd ///
	i.code i.year, cl(code) 
	
	margins, dydx(*) post
	eststo all
		
reg sat c.income_sd##c.fh lngdppc_sd trust_sd ideo_sd male_sd ///
	age_sd edu_sd growth_sd lninfl_sd ///
	i.code i.year, cl(code) 		
		
	margins, dydx(income_sd) at(fh=2) post
		eststo fh2
		
reg sat c.income_sd##c.fh lngdppc_sd trust_sd ideo_sd male_sd ///
	age_sd edu_sd growth_sd lninfl_sd ///
	i.code i.year, cl(code) 
	
	margins, dydx(income_sd) at(fh=10) post
		eststo fh6	
		
		
	coefplot /// 
		(all, keep(trust_sd ideo_sd male_sd age_sd edu_sd growth_sd lninfl_sd) ///
		ciopts(lcolor(black)) color(black) msymbol(O) msize(medlarge)) ///
		(fh2 , mlabel("FH=2") mlabp(12) mlabcolor(blue)  ///
		drop(_cons) ciopts(lcolor(black)) color(black) msymbol(O) msize(large)) ///
		(fh6 , mlabel("FH=10") mlabp(12) mlabcolor(red) ///
		drop(_cons) ciopts(lcolor(black)) color(black) msymbol(O) msize(large)) , ///
		offset(0) legend(off) name(coefplot_s, replace) ///
		title("B.Democracy") xline(0, lp(dash)) 
	

	gr export coefplot_fe.png, replace		

** Figure 4

reg sat c.income_sd##c.lngdppc fh_sd trust_sd ideo_sd male_sd ///
	age_sd edu_sd growth_sd lninfl_sd ///
	i.code i.year, cl(code) 
	
	margins, dydx(*) post
	eststo all2
		
reg sat c.income_sd##c.lngdppc fh_sd trust_sd ideo_sd male_sd ///
	age_sd edu_sd growth_sd lninfl_sd ///
	i.code i.year, cl(code) 	
		
	margins, dydx(income_sd) at(lngdppc=6.5) post
		eststo gd1
		
reg sat c.income_sd##c.lngdppc fh_sd trust_sd ideo_sd male_sd ///
	age_sd edu_sd growth_sd lninfl_sd ///
	i.code i.year, cl(code) 
	
	margins, dydx(income_sd) at(lngdppc=9.2) post
		eststo gd2	
		
		
	coefplot /// 
		(all2, keep(trust_sd ideo_sd male_sd age_sd edu_sd growth_sd lninfl_sd) ///
		ciopts(lcolor(black)) color(black) msymbol(O) msize(medlarge)) ///
		(gd1 , mlabel("G=6.5") mlabp(12) mlabcolor(blue)  ///
		drop(_cons) ciopts(lcolor(black)) color(black) msymbol(O) msize(large)) ///
		(gd2 , mlabel("G = 9.2") mlabp(12) mlabcolor(red) ///
		drop(_cons) ciopts(lcolor(black)) color(black) msymbol(O) msize(large)) , ///
		offset(0) legend(off) name(coefplot_s2, replace) ///
		title("A.GDPpc") xline(0, lp(dash)) 
	

	gr export coefplot_fe2.png, replace	
	gr combine  coefplot_s2 coefplot_s
	gr export fe_combined.png, replace


** Figures 5 and 6 (matching)
	
* to generate country-specific treatment variable (=poor)
** poor < (country-year mean) 
sort id
by id: egen temp_mean = mean(income)
* by id: egen temp_sd = sd(income)
* gen temp = temp_mean - (0.5)*temp_sd

gen treat = 0
replace treat = 1 if income < temp_mean
replace treat=. if income==.
drop temp_mean  /* temp_sd temp */

	
reg sat income fh lngdppc trust ideo male age edu  ///
	growth lninfl  

	gen temp=1 if e(sample)
	
drop if temp !=1
drop temp


tab id, gen(newid) // 1 -- 234.
*******************
* matching (Blackwell et al. 2009)

ssc install cem, replace	
ssc install cem, replace	
gen cem_b = .
gen cem_t=.
forvalues i=1/170 {
cem trust ideo male age edu if newid`i'==1 , treatment(treat)
reg sat treat if newid`i'==1 [iweight=cem_weights], r
replace cem_b = _b[treat] if newid`i'==1
replace cem_t = _b[treat] / _se[treat] if newid`i'==1
}
*

dups id, drop
drop _expand

twoway /// 
	(lfit cem_b lngdppc, lc(blue) lw(thick)) ///
	(scatter cem_b lngdppc, /// 
		msymbol(Oh) msize(large) mc(blue) ///
		name(cem_b, replace)), ///
	ytitle("Coefficients") xtitle("ln(GDPpc)") legend(off) /// 
	text(0.9 11 "b=0.096, p=0.000") title("A. Coefficient")
	
twoway /// 
	(lfit cem_t lngdppc if cem_t<4, lc(red) lw(thick)) /// /dropping one outlier 
	(scatter cem_t lngdppc, ///
		msymbol(Oh) msize(large) mc(red) ///
		name(cem_t, replace)), ///
	ytitle("t-value") xtitle("ln(GDPpc)") legend(off) ///
	text(4.9 11 "b=0.24, p=0.049") title("B. T-value")

cd "$data"
gr combine cem_b cem_t, c(2)
gr export matching.png, replace

twoway /// 
	(lfit cem_b fh, lc(blue) lw(thick)) ///
	(scatter cem_b fh, /// 
		msymbol(Oh) msize(large) mc(blue) /// 
		name(cem_b_demo, replace)) /// 
		, ///
	ytitle("Coefficients") xtitle("Freedom House") legend(off) /// 
	text(-2.75 11. "b=-0.034, p=0.001") title("A. Coefficient")
	
twoway /// 
	(lfit cem_t fh , lc(red) lw(thick)) /// /dropping one outlier 
	(scatter cem_t fh if cem_t< 4, ///
		msymbol(Oh) msize(large) mc(red) /// 
		name(cem_t_demo, replace)), ///
	ytitle("t-value") xtitle("Freedom House") legend(off) ///
	text(-10 10 "b=-0.113, p=0.024") title("B. T-value")
	
cd "$data"
gr combine cem_b_demo cem_t_demo, c(2)
gr export matching2.png, replace
	
